@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,6 +26,7 @@
 
 #include <string.h>
 
+#include "yelp-cache.h"
 #include "yelp-window.h"
 #include "yelp-section.h"
 #include "yelp-scrollkeeper.h"
@@ -63,17 +64,10 @@ impl_Yelp_newWindow (PortableServer_Servant  servant,
 		     CORBA_Environment      *ev)
 {
 	YelpBase  *yelp_base;
-	GtkWidget *window;
 	
 	yelp_base = YELP_BASE (bonobo_object (servant));
-	
-	window = yelp_base_new_window (yelp_base);
 
-	gtk_widget_show_all (window);
-
-	if (url && strcmp (url, "")) {
-		yelp_window_open_uri (YELP_WINDOW (window), url);
-	}
+	yelp_base_new_window (yelp_base, url);
 }
 
 static GNOME_Yelp_WindowList *
@@ -121,6 +115,8 @@ yelp_base_init (YelpBase *base)
 	priv->index    = NULL;
 	priv->windows  = NULL;
         base->priv     = priv;
+
+	yelp_cache_init ();
 }
 
 static void
@@ -142,7 +138,7 @@ yelp_base_new_window_cb (YelpWindow *window, YelpBase *base)
 	g_return_if_fail (YELP_IS_WINDOW (window));
 	g_return_if_fail (YELP_IS_BASE (base));
 	
-	new_window = yelp_base_new_window (base);
+	new_window = yelp_base_new_window (base, NULL);
 	
 	gtk_widget_show_all (new_window);
 }
@@ -176,11 +172,13 @@ yelp_base_new (void)
 	yelp_man_init (base->priv->toc_tree, &priv->index);
 	yelp_info_init (base->priv->toc_tree, &priv->index);
 	
+	priv->index = g_list_sort (priv->index, yelp_section_compare);
+
         return base;
 }
 
 GtkWidget *
-yelp_base_new_window (YelpBase *base)
+yelp_base_new_window (YelpBase *base, const gchar *str_uri)
 {
 	YelpBasePriv *priv;
 	GtkWidget    *window;
@@ -201,6 +199,15 @@ yelp_base_new_window (YelpBase *base)
 			  G_CALLBACK (yelp_base_new_window_cb),
 			  base);
 
+
+	gtk_widget_show_all (window);
+
+	if (str_uri && strcmp (str_uri, "")) {
+		yelp_window_open_uri (YELP_WINDOW (window), str_uri);
+	} else {
+		yelp_window_open_uri (YELP_WINDOW (window), "toc:");
+	}
+
 	return window;
 }
 
