@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * gnome-db2html3 - by John Fleck - based on Daniel Veillard's
  * xsltproc: user program for the XSL Transformation engine
@@ -27,7 +28,6 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <libgnome/gnome-i18n.h>
 #include <libxml/xmlversion.h>
 #include <libxml/xmlmemory.h>
 #include <libxml/debugXML.h>
@@ -42,7 +42,6 @@
 #include <libxslt/xsltInternals.h>
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
-#include <libgnomevfs/gnome-vfs-init.h>
 
 #include "yelp-error.h"
 
