@@ -434,6 +434,7 @@ reader_start (ReaderThreadData *th_data)
 	YelpReader         *reader;
 	YelpReaderPriv     *priv;
 	YelpURI            *uri;
+	gchar              *str_uri;
 	
 	g_return_val_if_fail (th_data != NULL, NULL);
 
@@ -483,10 +484,14 @@ reader_start (ReaderThreadData *th_data)
 	case YELP_URI_TYPE_PATH:
 		/* Hmm .. is this wrong or what?? */
 		break;
-	default:
-		g_assert_not_reached ();
+	case YELP_URI_TYPE_UNKNOWN:
+		str_uri = yelp_uri_to_string (uri);
+		gnome_url_show (str_uri, NULL);
+		g_free (str_uri);
 		
 		break;
+	default:
+		g_assert_not_reached ();
 	}
 
 	return NULL;
@@ -720,11 +725,15 @@ yelp_reader_new ()
 gboolean
 yelp_reader_start (YelpReader *reader, YelpURI *uri)
 {
-        YelpReaderPriv   *priv;
+	YelpReaderPriv   *priv;
 	ReaderThreadData *th_data;
 	gint              stamp;
-	gchar              *str_uri;
-
+	const gchar      *document = NULL;
+	gchar            *chunk = NULL;
+	gchar            *str_uri = NULL;
+	gchar             buffer[BUFFER_SIZE];
+	YelpURI	         *new_uri;
+	
 	g_return_val_if_fail (YELP_IS_READER (reader), FALSE);
 	g_return_val_if_fail (uri != NULL, FALSE);
 
@@ -747,61 +756,101 @@ yelp_reader_start (YelpReader *reader, YelpURI *uri)
 	th_data->uri    = yelp_uri_ref (uri);
 	th_data->stamp  = stamp;
 
-	if (yelp_uri_get_type (uri) == YELP_URI_TYPE_FILE ||
-	    yelp_uri_get_type (uri) == YELP_URI_TYPE_UNKNOWN ||
-	    yelp_uri_get_type (uri) == YELP_URI_TYPE_GHELP_OTHER) {
-		gboolean ret_val;
-		
-		str_uri = yelp_uri_to_string (uri);
-		ret_val = gnome_url_show (str_uri, NULL);
-		g_free (str_uri);
+	str_uri = yelp_uri_to_string (uri);
 
-		return ret_val;
+	if (str_uri && *str_uri) {
+		str_uri = look_for_html_help_file (str_uri);
+		new_uri = yelp_uri_new (str_uri);
+	} else {
+		new_uri = yelp_uri_copy (uri);
 	}
 
-	if (yelp_uri_get_type (uri) == YELP_URI_TYPE_DOCBOOK_XML || 
-	    yelp_uri_get_type (uri) == YELP_URI_TYPE_DOCBOOK_SGML) {
-		const gchar *document;
-		gchar *chunk;
+	g_free (str_uri);
 
-		document = yelp_cache_lookup (yelp_uri_get_path (uri));
-		
-		if (document) {
-			if (yelp_uri_get_section (uri) &&
-			    strcmp (yelp_uri_get_section (uri), "")) {
-				chunk = reader_get_chunk (document, 
-							  yelp_uri_get_section (uri));
-			} else {
-				chunk = reader_get_chunk (document, "toc");
+	if (yelp_uri_get_type (new_uri) == YELP_URI_TYPE_DOCBOOK_XML ||
+	    yelp_uri_get_type (new_uri) == YELP_URI_TYPE_DOCBOOK_SGML) {
+
+		/* check if there is HTML cache. If found, use the HTML cache. */
+		document = yelp_cache_lookup (yelp_uri_get_path (new_uri));
+	}
+	else if (yelp_uri_get_type (new_uri) == YELP_URI_TYPE_HTML) {
+		GnomeVFSHandle   *handle;
+		GnomeVFSResult    result;
+		GString          *html_buffer;
+		GnomeVFSFileSize  n;
+
+		result = gnome_vfs_open (&handle,
+					 yelp_uri_get_path (new_uri),
+					 GNOME_VFS_OPEN_READ);
+
+		if (result != GNOME_VFS_OK) {
+			/* FIXME: Signal error */
+			yelp_uri_unref (new_uri);
+			return FALSE;
+		}
+
+		html_buffer = NULL;
+
+		while (TRUE) {
+			result = gnome_vfs_read (handle, buffer,
+						 BUFFER_SIZE, &n);
+
+			/* FIXME: Do some error checking */
+			if (result != GNOME_VFS_OK) {
+				break;
 			}
-		
-			if (chunk) {
-				ReaderQueueData *q_data;
-				
-				q_data = reader_q_data_new (reader, stamp, 
-							    READER_QUEUE_TYPE_START);
-				g_async_queue_push (priv->thread_queue, 
-						    q_data);
 
-				q_data = reader_q_data_new (reader, stamp, 
-							    READER_QUEUE_TYPE_DATA);
-
-				q_data->data = chunk;
-				g_async_queue_push (priv->thread_queue, 
-						    q_data);
-				
-				q_data = reader_q_data_new (reader, stamp, 
-							    READER_QUEUE_TYPE_FINISHED);
-
-				g_async_queue_push (priv->thread_queue, 
-						    q_data);
-
-				g_idle_add ((GSourceFunc) reader_idle_check_queue, th_data);
-				return TRUE;
+			if (html_buffer == NULL) {
+				html_buffer = g_string_new (g_strndup (buffer,
+								       n));
+			} else {
+				html_buffer = g_string_append (html_buffer,
+							       g_strndup (buffer,
+									  n));
 			}
 		}
+
+		document = html_buffer->str;
+		g_string_free (html_buffer, FALSE);
 	}
-	
+
+	if (document) {
+		if (yelp_uri_get_section (new_uri) &&
+		    strcmp (yelp_uri_get_section (new_uri), "")) {
+			chunk = reader_get_chunk (document,
+						  yelp_uri_get_section (new_uri));
+		} else {
+			chunk = reader_get_chunk (document, "toc");
+		}
+
+		if (chunk) {
+			ReaderQueueData *q_data;
+
+			q_data = reader_q_data_new (reader, stamp,
+						    READER_QUEUE_TYPE_START);
+			g_async_queue_push (priv->thread_queue,
+					    q_data);
+
+			q_data = reader_q_data_new (reader, stamp,
+						    READER_QUEUE_TYPE_DATA);
+
+			q_data->data = chunk;
+			g_async_queue_push (priv->thread_queue,
+					    q_data);
+
+			q_data = reader_q_data_new (reader, stamp,
+						    READER_QUEUE_TYPE_FINISHED);
+			g_async_queue_push (priv->thread_queue,
+					    q_data);
+
+			g_idle_add ((GSourceFunc) reader_idle_check_queue,
+				    th_data);
+
+			yelp_uri_unref (new_uri);
+			return TRUE;
+		}
+	}
+
 	g_timeout_add (100, (GSourceFunc) reader_idle_check_queue, th_data);
 
 	g_thread_create_full ((GThreadFunc) reader_start, th_data,
@@ -809,6 +858,9 @@ yelp_reader_start (YelpReader *reader, YelpURI *uri)
 			      TRUE,
 			      FALSE, G_THREAD_PRIORITY_NORMAL,
 			      NULL /* FIXME: check for errors */);
+
+	yelp_uri_unref (new_uri);
+
 	return FALSE;
 }
 
@@ -827,3 +879,79 @@ yelp_reader_cancel (YelpReader *reader)
 
 	STAMP_MUTEX_UNLOCK;
 }
+
+
+/* Given an XML file, look if there is a cached HTML file. If the HTML is
+ * newer than XML, return it. Else return XML only.
+ */
+
+gchar *
+look_for_html_help_file (gchar *url)
+{
+	gchar *sect, *pos;
+	int len=0;
+	GString *path;
+	char    *html_url, *xml_url;
+	char    *scheme;
+	struct stat html_stat, xml_stat;
+
+	if (g_strrstr (url, ".xml") == NULL)
+		return url;
+
+	path = g_string_new (url);
+	sect = g_strrstr (url, "?");
+
+	len = sect - url;
+	path = g_string_truncate (path, len);
+
+	scheme = g_strrstr (path->str, ":");
+
+	xml_url = g_strdup (scheme + 1);
+
+	pos = g_strrstr (path->str, ".xml");
+
+	if (pos == NULL) {
+		g_string_free (path, TRUE);
+		g_free (xml_url);
+
+		return url;
+	}
+
+	len = pos - path->str;
+
+	path = g_string_truncate (path, len);
+
+	path = g_string_append (path, ".html");
+
+	scheme = g_strrstr (path->str, ":");
+
+	html_url = g_strdup (scheme + 1);
+
+	if (g_file_test (html_url, G_FILE_TEST_EXISTS)) {
+
+		stat (html_url, &html_stat);
+		stat (xml_url, &xml_stat);
+
+		g_free (xml_url);
+		g_free (html_url);
+
+		if (html_stat.st_mtime >= xml_stat.st_mtime) {
+
+			if (sect)
+				path = g_string_append (path, sect);
+
+			return g_string_free (path, FALSE);
+		}
+		else {
+			g_string_free (path, TRUE);
+			return url;
+		}
+	}
+	else {
+		g_free (xml_url);
+		g_free (html_url);
+		g_string_free (path, TRUE);
+
+		return url;
+	}
+}
