@@ -49,7 +49,7 @@
 
 typedef enum {
 	YELP_WINDOW_ACTION_BACK = 1,
-	YELP_WINDOW_ACTION_FORWARD,
+	YELP_WINDOW_ACTION_FORWARD
 } YelpHistoryAction;
 
 static GConfEnumStringPair toolbar_styles[] = {
@@ -141,9 +141,9 @@ struct _YelpWindowPriv {
 
 	GtkWidget      *notebook;
 
-	YelpViewTOC    *toc_view;
-	GtkWidget      *content_view;
-	GtkWidget      *index_view;
+	YelpView       *toc_view;
+	YelpView       *content_view;
+	YelpView       *index_view;
 	
 	GtkWidget      *view_current;
 
@@ -159,7 +159,6 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/_File"),              NULL,         0,                  0,                           "<Branch>"},
 	{N_("/File/_New window"),   NULL,         window_new_window_cb,   0,                           "<StockItem>", GTK_STOCK_NEW     },
 	{N_("/File/_Close window"), NULL,         window_close_window_cb, 0,                           "<StockItem>", GTK_STOCK_CLOSE   },
-/*	{N_("/File/_Quit"),         NULL,         window_exit_cb,         0,                           "<StockItem>", GTK_STOCK_QUIT    }, */
 	{N_("/_Go"),                NULL,         0,                  0,                           "<Branch>"},
 	{N_("/Go/_Back"),           NULL,         window_history_go_cb,   YELP_WINDOW_ACTION_BACK,     "<StockItem>", GTK_STOCK_GO_BACK    },
 	{N_("/Go/_Forward"),        NULL,         window_history_go_cb,   YELP_WINDOW_ACTION_FORWARD,  "<StockItem>", GTK_STOCK_GO_FORWARD },
@@ -299,18 +298,18 @@ window_populate (YelpWindow *window)
 					GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (sw), 
-			   yelp_view_toc_get_widget (priv->toc_view));
+			   priv->toc_view->widget);
 
 	gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
 				  sw, NULL, PAGE_TOC_VIEW);
 	
 	gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
-				  priv->content_view,
+				  priv->content_view->widget,
 				  NULL, PAGE_CONTENT_VIEW);
 
 	if (priv->index) {
 		gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
-					  priv->index_view,
+					  priv->index_view->widget,
 					  NULL, PAGE_INDEX_VIEW);
 	}
 	
@@ -342,7 +341,7 @@ window_handle_uri (YelpWindow *window, YelpURI *uri)
 	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_TOC) {
 		d(g_print ("[TOC]\n"));
 		
-		yelp_view_toc_open_uri (YELP_VIEW_TOC (priv->toc_view), uri);
+		yelp_view_show_uri (priv->toc_view, uri, NULL);
 
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_TOC_VIEW);
@@ -352,9 +351,7 @@ window_handle_uri (YelpWindow *window, YelpURI *uri)
 		d(g_print ("[INDEX]\n"));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_INDEX_VIEW);
-		yelp_view_index_show_uri (YELP_VIEW_INDEX (priv->index_view),
-					  uri, 
-					  &error);
+		yelp_view_show_uri (priv->index_view, uri, &error);
 		handled = TRUE;
 	}
 	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_MAN ||
@@ -366,9 +363,8 @@ window_handle_uri (YelpWindow *window, YelpURI *uri)
 		d(g_print ("[CONTENT]\n"));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_CONTENT_VIEW);
-		yelp_view_content_show_uri (YELP_VIEW_CONTENT (priv->content_view),
-					    uri,
-					    &error);
+		yelp_view_show_uri (priv->content_view,
+				    uri, &error);
 		handled = TRUE;
 	} else {
 		gnome_url_show (yelp_uri_to_string (uri), &error);
@@ -527,7 +523,7 @@ window_home_button_clicked (GtkWidget *button, YelpWindow *window)
 	uri = yelp_uri_new ("toc:");
 
 	yelp_history_goto (window->priv->history, uri);
-	yelp_view_toc_open_uri (window->priv->toc_view, uri);
+	yelp_view_show_uri (window->priv->toc_view, uri, NULL);
 
 	yelp_uri_unref (uri);
 
